@@ -1154,7 +1154,14 @@ DrawTile(MlinkWidget w, int pos, Boolean blank, Boolean erase, int offset)
 	if ((w->mlink.depth < 2 || w->mlink.mono) && offset) {
 		linkGC = borderGC;
 	} else {
-		linkGC = w->mlink.faceGC[((tile - 1) / w->mlink.tiles + 1) % w->mlink.faces];
+		int         face = ((tile - 1) / w->mlink.tiles + 1) % w->mlink.faces;
+
+		linkGC = w->mlink.faceGC[face];
+		if (w->mlink.depth >= 2 && !w->mlink.mono) {
+			if (((w->mlink.faceColor[face] == w->mlink.borderColor) && offset) ||
+			    ((w->mlink.faceColor[face] == w->mlink.tileColor) && !offset))
+				linkGC = borderGC;
+		}
 	}
 	dx = Row(w, pos) * w->mlink.offset.x + w->mlink.delta.x +
 		w->mlink.puzzleOffset.x + offset;
